@@ -60,6 +60,8 @@
 #include <ofono/gprs-context.h>
 #include <ofono/gnss.h>
 #include <ofono/handsfree.h>
+#include <ofono/siri.h>
+#include <ofono/sim-auth.h>
 
 #include <drivers/atmodem/vendor.h>
 #include <drivers/atmodem/atutil.h>
@@ -350,6 +352,65 @@ static void phonesim_ctm_set(struct ofono_ctm *ctm, ofono_bool_t enable,
 	g_free(cbd);
 }
 
+static gboolean phonesim_radio_settings_register(gpointer user)
+{
+	struct ofono_radio_settings *rs = user;
+
+	ofono_radio_settings_register(rs);
+
+	return FALSE;
+}
+
+static int phonesim_radio_settings_probe(struct ofono_radio_settings *rs,
+					unsigned int vendor, void *data)
+{
+	GAtChat *chat;
+
+	DBG("");
+
+	chat = g_at_chat_clone(data);
+
+	ofono_radio_settings_set_data(rs, chat);
+	g_idle_add(phonesim_radio_settings_register, rs);
+
+	return 0;
+}
+
+static void phonesim_radio_settings_remove(struct ofono_radio_settings *rs)
+{
+	GAtChat *chat = ofono_radio_settings_get_data(rs);
+
+	DBG("");
+
+	ofono_radio_settings_set_data(rs, NULL);
+
+	g_at_chat_unref(chat);
+}
+
+static void phonesim_query_rat_mode(struct ofono_radio_settings *rs,
+                                ofono_radio_settings_rat_mode_query_cb_t cb,
+				void *data)
+{
+	DBG("");
+
+	CALLBACK_WITH_SUCCESS(cb, OFONO_RADIO_ACCESS_MODE_ANY, data);
+}
+
+static void phonesim_query_available_rats(struct ofono_radio_settings *rs,
+			ofono_radio_settings_available_rats_query_cb_t cb,
+			void *data)
+{
+	uint32_t techs = 0;
+
+	DBG("");
+
+	techs |= OFONO_RADIO_ACCESS_MODE_GSM;
+	techs |= OFONO_RADIO_ACCESS_MODE_UMTS;
+	techs |= OFONO_RADIO_ACCESS_MODE_LTE;
+
+	CALLBACK_WITH_SUCCESS(cb, techs, data);
+}
+
 static struct ofono_gprs_context_driver context_driver = {
 	.name			= "phonesim",
 	.probe			= phonesim_context_probe,
@@ -358,6 +419,14 @@ static struct ofono_gprs_context_driver context_driver = {
 	.deactivate_primary	= phonesim_deactivate_primary,
 };
 
+static struct ofono_radio_settings_driver radio_settings_driver = {
+	.name			= "phonesim",
+	.probe			= phonesim_radio_settings_probe,
+	.remove			= phonesim_radio_settings_remove,
+	.query_rat_mode		= phonesim_query_rat_mode,
+	.query_available_rats	= phonesim_query_available_rats,
+};
+
 static struct ofono_ctm_driver ctm_driver = {
 	.name			= "phonesim",
 	.probe			= phonesim_ctm_probe,
@@ -790,6 +859,9 @@ static void phonesim_post_sim(struct ofono_modem *modem)
 
 	if (!data->calypso)
 		ofono_sms_create(modem, 0, "atmodem", data->chat);
+
+	ofono_radio_settings_create(modem, 0, "phonesim", data->chat);
+	ofono_sim_auth_create(modem);
 }
 
 static void phonesim_post_online(struct ofono_modem *modem)
@@ -957,6 +1029,7 @@ static void localhfp_pre_sim(struct ofono_modem *modem)
 	ofono_netreg_create(modem, 0, "hfpmodem", info);
 	ofono_call_volume_create(modem, 0, "hfpmodem", info);
 	ofono_handsfree_create(modem, 0, "hfpmodem", info);
+	ofono_siri_create(modem, 0, "hfpmodem", info);
 }
 
 static struct ofono_modem_driver localhfp_driver = {
@@ -1069,6 +1142,7 @@ done:
 static int phonesim_init(void)
 {
 	int err;
+	char *conf_override = getenv("OFONO_PHONESIM_CONFIG");
 
 	err = ofono_modem_driver_register(&phonesim_driver);
 	if (err < 0)
@@ -1078,8 +1152,12 @@ static int phonesim_init(void)
 
 	ofono_gprs_context_driver_register(&context_driver);
 	ofono_ctm_driver_register(&ctm_driver);
+	ofono_radio_settings_driver_register(&radio_settings_driver);
 
-	parse_config(CONFIGDIR "/phonesim.conf");
+	if (conf_override)
+		parse_config(conf_override);
+	else
+		parse_config(CONFIGDIR "/phonesim.conf");
 
 	return 0;
 }
@@ -1097,6 +1175,7 @@ static void phonesim_exit(void)
 	g_slist_free(modem_list);
 	modem_list = NULL;
 
+	ofono_radio_settings_driver_unregister(&radio_settings_driver);
 	ofono_ctm_driver_unregister(&ctm_driver);
 
 	ofono_gprs_context_driver_unregister(&context_driver);
